@@ -31,6 +31,7 @@ import subprocess
 import sys
 import traceback
 import signal
+import cairo
 
 gi.require_version("Gtk", "3.0")
 gi.require_version('UkuiPanelApplet', '4.0')
@@ -45,14 +46,13 @@ from ukui_menu.plugins.menu import pluginclass
 try:
     import xdg.Config
     import ukui_menu.keybinding as keybinding
-    import ukui_menu.pointerMonitor as pointerMonitor
     import ukui_menu.menueditor as menueditor
 except Exception as e:
     print (e)
     sys.exit( 1 )
 
 signal.signal(signal.SIGINT, signal.SIG_DFL)
-GObject.threads_init()
+#GObject.threads_init()
 
 # i18n
 gettext.install("ukui-menu", "/usr/share/locale")
@@ -67,8 +67,7 @@ from ukui_menu.execute import *
 class MainWindow( object ):
     """This is the main class for the application"""
 
-    def __init__( self, keybinder, settings ):
-        self.keybinder = keybinder
+    def __init__( self, settings ):
         self.settings = settings
 
         self.data_path = os.path.join( '/', 'usr', 'share', 'ukui-menu' )
@@ -84,28 +83,21 @@ class MainWindow( object ):
 
         builder.connect_signals(self)
 
-        self.borderwidth = 1
-        self.border.set_padding( self.borderwidth, self.borderwidth, self.borderwidth, self.borderwidth )
-        defaultStyle = self.getDefaultStyle()
-        color = defaultStyle.lookup_color('panel_normal_border_color')[1]
-        if color == Gdk.Color(red=0, green=0, blue=0):
-            self.window.modify_bg( Gtk.StateType.NORMAL, Gdk.color_parse( "#014276" ))
-        else:
-            self.window.modify_bg( Gtk.StateType.NORMAL, color )
+        self.borderwidth = 3
+#        self.border.set_padding( self.borderwidth, self.borderwidth, self.borderwidth, self.borderwidth )
+        self.border.set_margin_start( self.borderwidth )
+        self.border.set_margin_end( self.borderwidth )
+        self.border.set_margin_top( self.borderwidth )
+        self.border.set_margin_bottom( self.borderwidth )
         self.eventbox.set_name("EventBox")
 
         self.window.connect( "key-press-event", self.onKeyPress )
-        self.window.connect( "focus-in-event", self.onFocusIn )
         #设置window透明
-        #self.window.set_app_paintable(True)
-        #self.window.connect( "draw", self.onDrawEvent )
-        #self.window.connect( "screen-changed", self.onScreenChanged )
-        #self.paneholder.set_app_paintable(True)
-        #self.paneholder.connect( "draw", self.onDrawEvent )
-        #self.paneholder.connect( "screen-changed", self.onScreenChanged )
-        #self.onScreenChanged(None)
-        self.loseFocusId = self.window.connect( "focus-out-event", self.onFocusOut )
-        self.loseFocusBlocked = False
+        self.window.set_app_paintable(True)
+        opacity = self.settings.get_double("opacity")
+        self.window.set_opacity(opacity)
+        self.onScreenChanged(None)
+        self.window.connect( "focus-out-event", self.onFocusOut )
 
         self.offset = 0
 
@@ -117,7 +109,6 @@ class MainWindow( object ):
         Gtk.main_quit()
         sys.exit(0)
 
-
     def PopulatePlugins( self ):
         PluginPane = Gtk.EventBox()
         PluginPane.show()
@@ -140,7 +131,9 @@ class MainWindow( object ):
         VBox1 = Gtk.Box( orientation=Gtk.Orientation.VERTICAL )
         VBox1.show()
         #Add plugin to Plugin Box under heading button
-        MyPlugin.content_holder.reparent( VBox1 )
+        #MyPlugin.content_holder.reparent( VBox1 )
+        MyPlugin.window.remove( MyPlugin.content_holder )
+        VBox1.add( MyPlugin.content_holder )
 
         #Add plugin to main window
         PaneLadder.pack_start( VBox1 , True, True, 0)
@@ -224,38 +217,14 @@ class MainWindow( object ):
 
         self.window.hide()
 
-    def onFocusIn( self, *args ):
-        if self.loseFocusBlocked:
-            self.window.handler_unblock( self.loseFocusId )
-            self.loseFocusBlocked = False
-
-        return False
-
     def onFocusOut( self, *args):
-        if self.window.get_visible():
-            self.hide()
-        return False
-
-    def onDrawEvent( self, *args ):
-        cr = Gdk.cairo_create(self.window.get_window())
-        cr.set_source_rgba(0, 0, 0, 0.7)
-        cr.set_operator(cairo.OPERATOR_SOURCE)
-        cr.paint()
-        #cr.destroy()
+        self.hide()
         return False
 
     def onScreenChanged( self, *args ):
         screen = self.window.get_screen()
         visual = screen.get_rgba_visual()
         self.window.set_visual(visual)
-        screen = self.paneholder.get_screen()
-        visual = screen.get_rgba_visual()
-        self.paneholder.set_visual(visual)
-
-    def stopHiding( self ):
-        if not self.loseFocusBlocked:
-            self.window.handler_block( self.loseFocusId )
-            self.loseFocusBlocked = True
 
 class MenuWin( object ):
     def __init__( self, applet, iid ):
@@ -273,53 +242,46 @@ class MenuWin( object ):
         self.createPanelButton()
         self.applet.set_flags( UkuiPanelApplet.AppletFlags.EXPAND_MINOR )
         self.button.connect( "button-press-event", self.showMenu )
-        GLib.timeout_add(1000, self.InitMenu )
+        GLib.timeout_add(100, self.InitMenu )
 
     def InitMenu( self ):
         self.settings = Gio.Settings.new("org.ukui.ukui-menu")
         self.settings.connect("changed::show-category-menu", self.changeMenuState)
         self.settings.connect("changed::permission-changed", self.changeMenuState)
+        self.settings.connect("changed::opacity", self.changeOpacity)
 
         self.state = self.settings.get_boolean("show-category-menu")
 
-        self.keybinder = keybinding.GlobalKeyBinding()
+        GLib.timeout_add(30000, self.initKeybinder)
         self.hotkeyText = "Super_L"
-        self.mainwin = MainWindow( self.keybinder, self.settings )
+        self.mainwin = MainWindow( self.settings )
         self.mainwin.window.connect( "map-event", self.onWindowMap )
         self.mainwin.window.connect( "unmap-event", self.onWindowUnmap )
         self.mainwin.window.connect( "realize", self.onRealize )
         self.mainwin.window.connect( "size-allocate", lambda *args: self.positionMenu() )
         self.mainwin.window.connect( "focus-out-event", lambda *args: self.button.set_name("ButtonApplet") )
 
-        if self.keybinder is not None:
-            self.bind_hot_key()
         self.applet.set_can_focus(False)
 
-        self.pointerMonitor = pointerMonitor.PointerMonitor()
-        if self.pointerMonitor is not None:
-            self.pointerMonitor.connect("activate", self.onPointerOutside)
-        return False
+
+    def initKeybinder( self ):
+        self.keybinder = keybinding.GlobalKeyBinding()
+        if self.keybinder is not None:
+            self.bind_hot_key()
 
     def onWindowMap( self, *args ):
         self.applet.get_style_context().set_state( Gtk.StateFlags.SELECTED )
-        if self.keybinder == None:
-            return
 
-        self.keybinder.set_focus_window( self.mainwin.window.get_window() )
+        #self.keybinder.set_focus_window( self.mainwin.window.get_window() )
         return False
 
     def onWindowUnmap( self, *args ):
         self.applet.get_style_context().set_state( Gtk.StateFlags.NORMAL )
-        if self.keybinder == None:
-            return
         
-        self.keybinder.set_focus_window()
+        #self.keybinder.set_focus_window()
         return False
 
     def onRealize( self, *args):
-        self.pointerMonitor.addWindowToMonitor( self.mainwin.window.get_window() )
-        self.pointerMonitor.addWindowToMonitor( self.applet.get_window() )
-        self.pointerMonitor.start()
         return False
 
     def onPointerOutside(self, *args):
@@ -332,8 +294,7 @@ class MenuWin( object ):
 
     def changeIcon(self, settings, key, args = None):
         self.panel_size = self.settings_panel.get_int("size")
-        self.pixbuf = GdkPixbuf.Pixbuf.new_from_file("/usr/share/ukui-menu/icons/start.svg")
-        self.pixbuf = self.pixbuf.scale_simple(self.panel_size - 5, self.panel_size - 5, 2)
+        self.pixbuf = GdkPixbuf.Pixbuf.new_from_file_at_size("/usr/share/ukui-menu/icons/start.svg", self.panel_size, self.panel_size)
         self.button_icon.set_from_pixbuf(self.pixbuf)
         self.button_box.set_size_request(self.panel_size + 20, -1)
         Gdk.flush()
@@ -343,7 +304,6 @@ class MenuWin( object ):
         self.settings_panel.connect("changed::size", self.changeIcon)
         self.panel_size = self.settings_panel.get_int("size")
 
-
         style_provider = Gtk.CssProvider()
         try:
             css = open( os.path.join('/', 'usr', 'share', 'ukui-menu', 'ukuimenu.css'), 'rb')
@@ -354,8 +314,7 @@ class MenuWin( object ):
         except Exception as e:
             print (e)
 
-        self.pixbuf = GdkPixbuf.Pixbuf.new_from_file("/usr/share/ukui-menu/icons/start.svg")
-        self.pixbuf = self.pixbuf.scale_simple(self.panel_size - 5, self.panel_size - 5, 2)
+        self.pixbuf = GdkPixbuf.Pixbuf.new_from_file_at_size("/usr/share/ukui-menu/icons/start.svg", self.panel_size, self.panel_size)
         self.button_icon = Gtk.Image.new()
         self.button_icon.set_from_pixbuf(self.pixbuf)
         self.button_icon.set_tooltip_text(_("Start"))
@@ -365,13 +324,17 @@ class MenuWin( object ):
         self.button_box = Gtk.Box()
         self.button_box.set_size_request(self.panel_size + 20, -1)
         self.button_box.pack_start( self.button , True, True, 0)
-        self.button_icon.set_padding( 0, 0 )
+        #self.button_icon.set_padding( 0, 0 )
+        self.button_icon.set_margin_start( 0 )
+        self.button_icon.set_margin_end( 0 )
+        self.button_icon.set_margin_top( 0 )
+        self.button_icon.set_margin_bottom( 0 )
 
         self.button_box.set_homogeneous( False )
         self.button_box.show_all()
 
         self.applet.add( self.button_box )
-        self.applet.set_background_widget( self.applet )
+        #self.applet.set_background_widget( self.applet )
 
     def bind_hot_key( self ):
         try:
@@ -404,6 +367,8 @@ class MenuWin( object ):
         window.set_default_icon(GdkPixbuf.Pixbuf.new_from_file("/usr/share/ukui-menu/icons/start.svg"))
 
         window.set_title(_("Menu Property"))
+        labelOpacity = builder.get_object("label_opacity")
+        labelOpacity.set_text(_("Transparency:"))
         labelMenu = builder.get_object("label1")
         labelMenu.set_text(_("Menu Type:"))
         labelMenu.set_tooltip_text(_("This is used to set up the menu type."))
@@ -445,6 +410,11 @@ class MenuWin( object ):
         recent_app_num = self.mainwin.settings.get_int("recent-app-num")
         self.recent_app_num_bt.set_value(recent_app_num)
 
+        self.opacity = builder.get_object("opacity")
+        self.opacity.connect("value-changed", self.opacity_changed)
+        opacity = self.mainwin.settings.get_double("opacity")
+        self.opacity.set_value(opacity)
+
         self.resetButton = builder.get_object("button2")
         self.resetButton.set_label(_("Reset to default(_R)"))
         self.resetButton.set_use_underline(True)
@@ -463,6 +433,7 @@ class MenuWin( object ):
         self.mainwin.settings.reset("show-recent-file")
         self.mainwin.settings.reset("recent-file-num")
         self.mainwin.settings.reset("recent-app-num")
+        self.mainwin.settings.reset("opacity")
         state = self.mainwin.settings.get_boolean("show-category-menu")
         if state:
             self.radioButton2.set_active(True)
@@ -475,11 +446,16 @@ class MenuWin( object ):
             self.switchButton.set_state(False)
         self.recent_file_num_bt.set_value(self.mainwin.settings.get_int("recent-file-num"))
         self.recent_app_num_bt.set_value(self.mainwin.settings.get_int("recent-app-num"))
+        self.opacity.set_value(self.mainwin.settings.get_double("opacity"))
 
     def value_file_changed( self, widget ):
         num = widget.get_value_as_int()
         self.mainwin.settings.set_int("recent-file-num", num)
 
+    def opacity_changed( self, widget ):
+        value = widget.get_value()
+        self.mainwin.settings.set_double("opacity", value)
+
     def value_app_changed( self, widget ):
         num = widget.get_value_as_int()
         self.mainwin.settings.set_int("recent-app-num", num)
@@ -574,6 +550,10 @@ class MenuWin( object ):
 
         self.mainwin.RegenPlugins()
 
+    def changeOpacity(self, settings, key, args = None):
+        opacity = self.mainwin.settings.get_double("opacity")
+        self.mainwin.window.set_opacity(opacity)
+
     def LoadNormalMenu( self, *args, **kargs ):
         if self.mainwin is None:
             return
@@ -620,6 +600,8 @@ class MenuWin( object ):
 
         xml = os.path.join( self.data_path, "popup.xml" )
         self.applet.setup_menu_from_file(xml, action_group)
+        if self.mainwin.window.get_visible():
+            self.mainwin.window.hide()
 
 def applet_factory( applet, iid, data ):
     MenuWin( applet, iid )
